# This file was auto-generated by Fern from our API Definition.

from ....core.unchecked_base_model import UncheckedBaseModel
from .agents_create_request_initial_message_sequence_item_role import AgentsCreateRequestInitialMessageSequenceItemRole
import typing
from ....core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class AgentsCreateRequestInitialMessageSequenceItem(UncheckedBaseModel):
    role: AgentsCreateRequestInitialMessageSequenceItemRole
    content: str
    name: typing.Optional[str] = None
    otid: typing.Optional[str] = None
    sender_id: typing.Optional[str] = None
    batch_item_id: typing.Optional[str] = None
    group_id: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
