# This file was auto-generated by Fern from our API Definition.

import typing

ChatCompletionAudioParamVoice = typing.Union[
    str,
    typing.Literal["alloy"],
    typing.Literal["ash"],
    typing.Literal["ballad"],
    typing.Literal["coral"],
    typing.Literal["echo"],
    typing.Literal["fable"],
    typing.Literal["onyx"],
    typing.Literal["nova"],
    typing.Literal["sage"],
    typing.Literal["shimmer"],
    typing.Literal["verse"],
]
