# This file was auto-generated by Fern from our API Definition.

import typing
from ....types.letta_request import LettaRequest
from ....types.letta_streaming_request import LettaStreamingRequest

MessagesPreviewRawPayloadRequest = typing.Union[LettaRequest, LettaStreamingRequest]
