# This file was auto-generated by Fern from our API Definition.

import typing

StopReasonType = typing.Union[
    typing.Literal["end_turn", "error", "invalid_tool_call", "max_steps", "no_tool_call", "tool_rule", "cancelled"],
    typing.Any,
]
